@@ -24,12 +24,15 @@ For more information, see https://drdoctr.github.io/doctr/docs/
 import sys
 import os
 import argparse
+import shlex
+import subprocess
 
 from textwrap import dedent
 
 from .local import (generate_GitHub_token, encrypt_variable, encrypt_file,
     upload_GitHub_deploy_key, generate_ssh_key, check_repo_exists)
-from .travis import setup_GitHub_push, commit_docs, push_docs, get_current_repo
+from .travis import (setup_GitHub_push, commit_docs, push_docs,
+    get_current_repo, sync_from_log, find_sphinx_build_dir, run)
 from . import __version__
 
 def get_parser():
@@ -60,13 +63,21 @@ options available.
     deploy_parser.add_argument('--gh-pages-docs', default='docs',
         help="""Directory to deploy the html documentation to on gh-pages. The
         default is %(default)r.""")
-    deploy_parser.add_argument('--tmp-dir', default='_docs',
-        help="""Temporary directory used on gh-pages. The default is %(default)r.""")
+    deploy_parser.add_argument('--tmp-dir', default=None,
+        help=argparse.SUPPRESS)
     deploy_parser.add_argument('--deploy-repo', default=None, help="""Repo to
         deploy the docs to. By default, it deploys to the repo Doctr is run from.""")
     deploy_parser.add_argument('--no-require-master', dest='require_master', action='store_false',
         default=True, help="""Allow docs to be pushed from a branch other than master""")
-
+    deploy_parser.add_argument('--command', default=None, help="""Command to
+        be run before committing and pushing. If the command creates
+        additional files that should be deployed, they should be added to the
+        index.""")
+    deploy_parser.add_argument('--no-sync', dest='sync', action='store_false',
+        default=True, help="""Don't sync any files. This is generally used in
+        conjunction with the --command flag, for instance, if the command syncs
+        the files for you. Any files you wish to commit should be added to the
+        index.""")
 
     configure_parser = subcommand.add_parser('configure', help="Configure doctr. This command should be run locally (not on Travis).")
     configure_parser.set_defaults(func=configure)
@@ -106,15 +117,41 @@ def deploy(args, parser):
         parser.error("doctr does not appear to be running on Travis. Use "
             "doctr deploy --force to run anyway.")
 
+    if args.tmp_dir:
+        parser.error("The --tmp-dir flag has been removed (doctr no longer uses a temporary directory when deploying).")
+
     build_repo = get_current_repo()
     deploy_repo = args.deploy_repo or build_repo
 
-    if setup_GitHub_push(deploy_repo, auth_type='token' if args.token else
-                         'deploy_key', full_key_path=args.key_path,
-                         require_master=args.require_master):
-        commit_docs(built_docs=args.built_docs,
-            gh_pages_docs=args.gh_pages_docs, tmp_dir=args.tmp_dir)
-        push_docs()
+    current_commit = subprocess.check_output(['git', 'rev-parse', 'HEAD']).decode('utf-8').strip()
+    try:
+        if setup_GitHub_push(deploy_repo, auth_type='token' if args.token else
+                             'deploy_key', full_key_path=args.key_path,
+                             require_master=args.require_master):
+
+            if args.sync:
+                if not args.built_docs:
+                    built_docs = find_sphinx_build_dir()
+
+                log_file = os.path.join(args.gh_pages_docs, '.doctr-files')
+
+                print("Moving built docs into place")
+                added, removed = sync_from_log(src=built_docs,
+                    dst=args.gh_pages_docs, log_file=log_file)
+
+            else:
+                added, removed = [], []
+
+            if args.command:
+                run(shlex.split(args.command))
+
+            changes = commit_docs(added=added, removed=removed)
+            if changes:
+                push_docs()
+            else:
+                print("The docs have not changed. Not updating")
+    finally:
+        run(['git', 'checkout', current_commit])
 
 class IncrementingInt:
     def __init__(self, i=0):
@@ -201,7 +238,7 @@ def configure(args, parser):
     {N}. Add
 
         - pip install doctr
-        - doctr deploy {options}
+        - doctr deploy{options}
 
     to the docs build of your .travis.yml.
     """.format(options=options, N=N)))
